<!-- markdownlint-disable -->

<a href="https://github.com/henriqueslab/rxiv-maker/blob/main/src/src/rxiv_maker/utils/citation_utils.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `citation_utils.py`
Citation handling utilities for Rxiv-Maker. 


---

<a href="https://github.com/henriqueslab/rxiv-maker/blob/main/src/src/rxiv_maker/utils/citation_utils.py#L8"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `inject_rxiv_citation`

```python
inject_rxiv_citation(yaml_metadata: dict[str, Any]) → None
```

Inject Rxiv-Maker citation into bibliography if acknowledge_rxiv_maker is true. 



**Args:**
 
 - <b>`yaml_metadata`</b>:  The YAML metadata dictionary. 


